@@ -11,7 +11,7 @@ MI.quantile <- function(imp.model, L, data)
     imp.modelk <- imp.glm[[k]]
 
 	for (l in 1:L){
-      impvar <- paste(imp.modelk$formula[[2L]])
+      impvar <- all.vars(imp.modelk$formula)[1L]
       fam <- imp.modelk$family$family
       # link <- imp.modelk$family$link
       # coeff <- coef(imp.modelk)
@@ -25,8 +25,6 @@ MI.quantile <- function(imp.model, L, data)
       }
 
 	  else if (fam == "binomial"){
-	    # if (any(m < 0) | any(m > 1))
-        #   stop(paste("imputation model ", k, " is not appropriate, estimated probability should be within [0,1] for 'binomial' family; specify a different imputation model"))
         if (any(wts.tmp %% 1 != 0))
           stop("cannot simulate from non-integer prior.weights")
 
@@ -40,8 +38,6 @@ MI.quantile <- function(imp.model, L, data)
       }
 
       else if (fam == "poisson"){
-        # if (any(m <= 0))
-        #   stop(paste("imputation model ", k, " is not appropriate, estimated mean should be non-negative for 'Poisson' family; specify a different imputation model"))
         imp <- rpois(n, lambda = m)
       }
 
@@ -50,8 +46,6 @@ MI.quantile <- function(imp.model, L, data)
         #   stop("need CRAN package 'MASS' for simulation from the 'Gamma' family")
         # shape <- MASS::gamma.shape(imp.modelk)$alpha * wts.tmp
 		shape <- 1 / summary(imp.modelk)$dispersion * wts.tmp
-        # if (any(shape <= 0) | any(shape / m <= 0))
-		#   stop(paste("imputation model ", k, " is not appropriate, estimated shape and rate should be positive for 'Gamma' family; specify a different imputation model"))
         imp <- rgamma(n, shape = shape, rate = shape / m)
       }
 
@@ -59,8 +53,6 @@ MI.quantile <- function(imp.model, L, data)
         if(!requireNamespace("SuppDists", quietly = TRUE))
           stop("need CRAN package 'SuppDists' for simulation from the 'inverse.gaussian' family")
 		disp <- summary(imp.modelk)$dispersion
-        # if (any(m <= 0) | any(disp <= 0))
-		#   stop(paste("imputation model ", k, " is not appropriate, estimated mean should be positive for 'inverse.gaussian' family; specify a different imputation model"))
         imp <- SuppDists::rinvGauss(n, nu = m, lambda = wts.tmp / disp)
       }
 
@@ -201,14 +193,15 @@ MR.quantile <- function(response, tau = 0.5, imp.model = NULL, mis.model = NULL,
   # Bootstrap method for variance estimation
   if (bootstrap == TRUE){
     set.seed(bootstrap.size)
-    bs.est <- rep(0, bootstrap.size)
-    n <- NROW(data)
-    for (b in 1:bootstrap.size){
+    bbb <- function(response, tau, imp.model, mis.model, L, data){
+      n <- NROW(data)
       bs.sample <- data[sample(1:n, n, replace = TRUE), ]
       while (any(colSums(is.na(bs.sample)) == n)) { bs.sample <- data[sample(1:n, n, replace = TRUE), ] }
-      bs.est[b] <- MREst.quantile(response = response, tau = tau, imp.model = imp.model, mis.model = mis.model, L = L, data = bs.sample)
+      b.est <- MREst.quantile(response = response, tau = tau, imp.model = imp.model, mis.model = mis.model, L = L, data = bs.sample)
+      return(b.est)
     }
 
+    bs.est <- replicate(bootstrap.size, bbb(response = response, tau = tau, imp.model = imp.model, mis.model = mis.model, L = L, data = data))
     se <- sd(bs.est) # bootstrap standard error
     cilb <- est - qnorm(1 - alpha / 2) * se
     ciub <- est + qnorm(1 - alpha / 2) * se
